[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Re: [MiNT] Re: -m68020-60 option of GCC 2.8.1



LE COAT Francois <lecoat@ief.ief.u-psud.fr> writes:

|> In fact, when I compile -m68060 or -m68020-60, GCC produces
|> the FMOVECR instruction that is not implemented on the
|> 68060. Is that a bug of GCC ?

Yes.  Here is a patch:

Index: m68k.c
===================================================================
RCS file: /home/gd/gnu/cvsroot/gcc/config/m68k/m68k.c,v
retrieving revision 1.84
retrieving revision 1.85
diff -u -a -r1.84 -r1.85
--- m68k.c	1997/11/21 10:53:35	1.84
+++ m68k.c	1998/04/02 12:05:30	1.85
@@ -1,5 +1,5 @@
 /* Subroutines for insn-output.c for Motorola 68000 family.
-   Copyright (C) 1987, 93, 94, 95, 96, 1997 Free Software Foundation, Inc.
+   Copyright (C) 1987, 93, 94, 95, 96, 97, 1998 Free Software Foundation, Inc.
 
 This file is part of GNU CC.
 
@@ -2407,8 +2407,9 @@
   return 0;
 #endif
 
-  /* fmovecr must be emulated on the 68040, so it shouldn't be used at all. */
-  if (TARGET_68040)
+  /* fmovecr must be emulated on the 68040 and 68060, so it shouldn't be
+     used at all on those chips. */
+  if (TARGET_68040 || TARGET_68060)
     return 0;
 
 #ifndef REAL_ARITHMETIC

-- 
Andreas Schwab                                      "And now for something
schwab@issan.cs.uni-dortmund.de                      completely different"
schwab@gnu.org